@@ -1,10 +1,10 @@
 from click import command, argument, option
-from cloudinary import uploader
+from cloudinary import uploader as upload_api
 
 from cloudinary_cli.core.overrides import upload
 from cloudinary_cli.utils.api_utils import handle_api_command
 
-uploader.upload = upload
+upload_api.upload = upload
 
 
 @command("uploader",
@@ -29,5 +29,5 @@ Format: cld <cli options> uploader <command options> <method> <method parameters
 def uploader(params, optional_parameter, optional_parameter_parsed, ls, save, doc):
     return handle_api_command(params, optional_parameter, optional_parameter_parsed, ls, save, doc,
                               doc_url="https://cloudinary.com/documentation/image_upload_api_reference",
-                              api_instance=uploader,
+                              api_instance=upload_api,
                               api_name="upload")
